---
name: "⚠️ Security Report"
about: "Report an issue to help the project improve."
title: ""
labels: "Type: Security"


---

<!--📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛

Oh, hi there! 😄

To expedite issue processing, please search open and closed issues before submitting a new one.
Please read our Rules of Conduct at this repository's `.github/CODE_OF_CONDUCT.md`

FIRST OF ALL, read this project's SECURITY.md file. Located in `.github/SECURITY.md`.

READ CAREFULLY IF YOUR ISSUE REPORT CONTAINS SENSIBLE OR PRIVATE DATA:
(data that might be leaked or subtracted from our servers due to this
security issue).

If this security report (or the guide on how to "identify the security bug") includes
certain personal information or involves personal identifiable data, or you believe
that the data that you might leak by exposing the way on how to attack the project
could be considered as a data leak or could violate the privacy of any kind of
data or sensible data, please do not post it here and directly email the developer:
(jgracia9988@gmail.com). You should post the issue with the least amount of
sensible or private data as possible to help us manage the security issue, and
with the extra data sent from your email to the developer (if any), we will deeply
analyze and try to fix it as fast as possible.

If you are in doubt about the data that you might post here (screenshots or media
also, count as data), please directly email us.

The data that must NOT be posted here:

* Legal and/or full names
* Names or usernames combined with other identifiers like phone numbers or email addresses
* Health or financial information (including insurance information, social security numbers, etc.)
* Information about political or religious affiliations
* Information about race, ethnicity, sexual orientation, gender, or other identifying information that could be used for discriminatory purposes

📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛-->

# **⚠️ Security Report**

## **Describe the security issue**
<!-- A clear and concise description of what the bug is. -->

*

---

### **To Reproduce**

<!-- Steps to reproduce the error:
(e.g.:)
1. Use x argument / navigate to
2. Fill this information
3. Go to...
4. See error -->

<!-- Write the steps here (add or remove as many steps as needed)-->

1.
2.
3.
4.

---

### **Expected behaviour**
<!-- A clear and concise description of what you expected to happen. -->

*

---

### **Media prove**
<!-- If applicable, add screenshots or videos to help explain your problem. -->

---

### **Your environment**

<!-- use all the applicable bulleted list elements for this specific issue,
and remove all the bulleted list elements that are not relevant for this issue. -->

* OS: <!--[e.g. Ubuntu 5.4.0-26-generic x86_64 / Windows 1904 ...]-->
* Python version:
* Pip version:

---

### **Additional context**
<!-- Add any other context or additional information about the problem here.-->

*
